pub struct Arena<T> { /* private fields */ }Expand description
An append-only arena with typed Handle-based access.
Implementations
Sourceimpl<T> Arena<T>
impl<T> Arena<T>
Sourcepub fn next_handle(&self) -> Handle<T>
pub fn next_handle(&self) -> Handle<T>
Returns the handle that will be assigned to the next appended value.
Sourcepub fn try_get(&self, handle: Handle<T>) -> Option<&T>
pub fn try_get(&self, handle: Handle<T>) -> Option<&T>
Returns a reference to the value if the handle is valid.